setwd('E:/')

#######
#SETUP#
#######

rm(list=ls())

data<-read.csv('moths2014_data.csv',h=T,colClasses=c('factor','factor','factor','factor','factor','factor','factor','numeric','factor','factor','integer'))
str(data)

#Aggregate counts by survey location
library(nlme)
data<-gsummary(object=data,groups=paste(data$location,data$species),FUN=sum)
row.names(data)<-NULL
data$specialism<-relevel(data$specialism,ref='gra')

#Produce simpler nested versions of the "management" variable
data$management<-relevel(data$management,ref='aesi1')
#This variable doesn't distinguish between the two types of "arable field centre"
data$manage_AES<-data$management
data$manage_AES[data$manage_AES=='aesi0']<-'ctrl0'
unique(data$manage_AES)
#This variable doesn't distinguish between AES interventions and control margins
data$manage_loc<-data$manage_AES
data$manage_loc[data$manage_loc=='aesi1']<-'ctrl1'
data$manage_loc<-relevel(data$manage_loc,ref='ctrl1')
unique(data$manage_loc)

#Produce a grouping for species nested within landscape
data$species_ls<-paste(data$landscape,data$species,sep='_')

#Produce a unique identifier for each observation
data$ID<-factor(1:length(data[,1]))
str(data)

#######
#GLMMs#
#######

#examples of GLMMs
library(lme4)

model33<-glmer(count~manage_AES+(1|ID)+(1|field)+(1|date)+(1|species_ls),
              data=data,family=poisson,
              #next line changes optimiser to check for convergence under a preferred method
              control=glmerControl(optimizer="bobyqa")
)
summary(model33)

model1<-glmer(count~manage_AES*connect_CG*specialism+(1|ID)+(1|field)+(1|date)+(1|species_ls),
               data=data,family=poisson,
               #next line changes optimiser to check for convergence under a preferred method
               control=glmerControl(optimizer="bobyqa")
)
summary(model1)

#Example of dredging a saturated model
library(MuMIn)

options(na.action = "na.fail")
dredge1<-dredge(model1)